summaryrefslogtreecommitdiffstats
path: root/kdeui/kcombobox.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-07 03:45:53 +0000
commit10308be19ef7fa44699562cc75946e7ea1fdf6b9 (patch)
tree4bc444c00a79e88105f2cfce5b6209994c413ca0 /kdeui/kcombobox.h
parent307136d8eef0ba133b78ceee8e901138d4c996a1 (diff)
downloadtdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.tar.gz
tdelibs-10308be19ef7fa44699562cc75946e7ea1fdf6b9.zip
Revert automated changes
Sorry guys, they are just not ready for prime time Work will continue as always git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1212479 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdeui/kcombobox.h')
-rw-r--r--kdeui/kcombobox.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kdeui/kcombobox.h b/kdeui/kcombobox.h
index 0a23fe85a..d7d07e4b6 100644
--- a/kdeui/kcombobox.h
+++ b/kdeui/kcombobox.h
@@ -234,7 +234,7 @@ public:
*
* If @p true, the completion mode will be set to automatic.
* Otherwise, it is defaulted to the global setting. This
- * method has been tqreplaced by the more comprehensive
+ * method has been replaced by the more comprehensive
* setCompletionMode().
*
* @param autocomplete Flag to enable/disable automatic completion mode.
@@ -245,7 +245,7 @@ public:
* Re-implemented from TQComboBox.
*
* Returns @p true if the current completion mode is set
- * to automatic. See its more comprehensive tqreplacement
+ * to automatic. See its more comprehensive replacement
* completionMode().
*
* @return @p true when completion mode is automatic.
@@ -299,7 +299,7 @@ public:
*
* @return @p true if an item with the string @p text is in the combobox.
*/
- bool tqcontains( const TQString& text ) const;
+ bool contains( const TQString& text ) const;
/**
* By default, KComboBox recognizes Key_Return and Key_Enter
@@ -360,7 +360,7 @@ signals:
* Emitted when the user presses the Enter key.
*
* The argument is the current text being edited. This signal is just like
* returnPressed() except it tqcontains the current text as its argument.
*
* Note that this signal is only emitted when the
* widget is editable.
@@ -360,7 +360,7 @@ signals:
*
* The argument is the current text being edited. This signal is just like
- * returnPressed() except it tqcontains the current text as its argument.
+ * returnPressed() except it contains the current text as its argument.
*
* Note that this signal is only emitted when the